==> ews-javascript-api-0.1.8.tgz: package/js/ComplexProperties/EmailAddress.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var XmlNamespace_1 = require("../Enumerations/XmlNamespace");
var ItemId_1 = require("./ItemId");
var MailboxType_1 = require("../Enumerations/MailboxType");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var ExtensionMethods_1 = require("../ExtensionMethods");
var ComplexProperty_1 = require("./ComplexProperty");
var EmailAddress = (function (_super) {
    __extends(EmailAddress, _super);
    function EmailAddress() {
        _super.apply(this, arguments);
        this.name = null;
        this.address = null;
        this.routingType = null;
        this.mailboxType = null;
        this.id = null;
    }
    Object.defineProperty(EmailAddress.prototype, "Name", {
        get: function () {
            return this.name;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.name; }, setValue: function (updateValue) { _this.name = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmailAddress.prototype, "Address", {
        get: function () {
            return this.address;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.address; }, setValue: function (updateValue) { _this.address = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmailAddress.prototype, "RoutingType", {
        get: function () {
            return this.routingType;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.routingType; }, setValue: function (updateValue) { _this.routingType = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmailAddress.prototype, "MailboxType", {
        get: function () {
            return this.mailboxType;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.mailboxType; }, setValue: function (updateValue) { _this.mailboxType = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmailAddress.prototype, "Id", {
        get: function () {
            return this.id;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.id; }, setValue: function (updateValue) { _this.id = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    EmailAddress.prototype.InternalToJson = function (service) { throw new Error("EmailAddress.ts - InternalToJson : Not implemented."); };
    EmailAddress.prototype.LoadFromJson = function (jsonProperty, service) { throw new Error("EmailAddress.ts - LoadFromJson : Not implemented."); };
    EmailAddress.prototype.ToString = function () {
        var addressPart = null;
        if (ExtensionMethods_1.StringHelper.IsNullOrEmpty(this.Address)) {
            return ExtensionMethods_1.StringHelper.Empty;
        }
        if (!ExtensionMethods_1.StringHelper.IsNullOrEmpty(this.RoutingType)) {
            addressPart = this.RoutingType + ":" + this.Address;
        }
        else {
            addressPart = this.Address;
        }
        if (!ExtensionMethods_1.StringHelper.IsNullOrEmpty(this.Name)) {
            return this.Name + " <" + addressPart + ">";
        }
        else {
            return addressPart;
        }
    };
    EmailAddress.prototype.ReadElementsFromXmlJsObject = function (reader) { throw new Error("EmailAddress.ts - TryReadElementFromXmlJsObject : Not implemented."); };
    //todo: implement UpdateFromXmlJsObject
    EmailAddress.prototype.LoadFromXmlJsObject = function (jsonProperty, service) {
        for (var key in jsonProperty) {
            switch (key) {
                case XmlElementNames_1.XmlElementNames.Name:
                    this.name = jsonProperty[key]; //.ReadAsString(key);
                    break;
                case XmlElementNames_1.XmlElementNames.EmailAddress:
                    this.address = jsonProperty[key]; //.ReadAsString(key);
                    break;
                case XmlElementNames_1.XmlElementNames.RoutingType:
                    this.routingType = jsonProperty[key]; //.ReadAsString(key);
                    break;
                case XmlElementNames_1.XmlElementNames.MailboxType:
                    this.mailboxType = MailboxType_1.MailboxTypeParser.FromString(jsonProperty[key]); //.ReadEnumValue<MailboxType>(key);
                    break;
                case XmlElementNames_1.XmlElementNames.ItemId:
                    this.id = new ItemId_1.ItemId();
                    this.id.LoadFromXmlJsObject(jsonProperty[key], service);
                    break;
                default:
                    break;
            }
        }
    };
    EmailAddress.prototype.WriteElementsToXml = function (writer) {
        writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, XmlElementNames_1.XmlElementNames.Name, this.Name);
        writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, XmlElementNames_1.XmlElementNames.EmailAddress, this.Address);
        writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, XmlElementNames_1.XmlElementNames.RoutingType, this.RoutingType);
        writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, XmlElementNames_1.XmlElementNames.MailboxType, MailboxType_1.MailboxTypeParser.ToString(this.MailboxType));
        if (this.Id != null) {
            this.Id.WriteToXml(writer); //, XmlElementNames.ItemId);
        }
    };
    EmailAddress.SmtpRoutingType = "SMTP";
    return EmailAddress;
})(ComplexProperty_1.ComplexProperty);
exports.EmailAddress = EmailAddress;

==> ews-javascript-api-0.1.11.tgz: package/js/ComplexProperties/EmailAddress.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var XmlNamespace_1 = require("../Enumerations/XmlNamespace");
var ItemId_1 = require("./ItemId");
var MailboxType_1 = require("../Enumerations/MailboxType");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var ExtensionMethods_1 = require("../ExtensionMethods");
var EwsUtilities_1 = require("../Core/EwsUtilities");
var ComplexProperty_1 = require("./ComplexProperty");
var EmailAddress = (function (_super) {
    __extends(EmailAddress, _super);
    function EmailAddress(smtpAddressOrNameOrMailbox, smtpAddressOrAddress, routingType, mailboxType, itemId) {
        _super.call(this);
        this.name = null;
        this.address = null;
        this.routingType = null;
        this.mailboxType = null;
        this.id = null;
        if (smtpAddressOrNameOrMailbox instanceof EmailAddress) {
            EwsUtilities_1.EwsUtilities.ValidateParam(smtpAddressOrNameOrMailbox, "mailbox");
            this.Name = smtpAddressOrNameOrMailbox.Name;
            this.Address = smtpAddressOrNameOrMailbox.Address;
            this.RoutingType = smtpAddressOrNameOrMailbox.RoutingType;
            this.MailboxType = smtpAddressOrNameOrMailbox.MailboxType;
            this.Id = smtpAddressOrNameOrMailbox.Id;
        }
        else {
            var argsLength = arguments.length;
            if (argsLength === 1) {
                this.address = smtpAddressOrNameOrMailbox;
            }
            else if (argsLength > 1) {
                this.name = smtpAddressOrNameOrMailbox;
                this.address = smtpAddressOrAddress;
                if (argsLength >= 3) {
                    this.routingType = routingType;
                }
                if (argsLength >= 4) {
                    this.mailboxType = mailboxType;
                }
                if (argsLength === 5) {
                    this.id = itemId;
                }
            }
        }
    }
    Object.defineProperty(EmailAddress.prototype, "Name", {
        get: function () {
            return this.name;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.name; }, setValue: function (updateValue) { _this.name = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmailAddress.prototype, "Address", {
        get: function () {
            return this.address;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.address; }, setValue: function (updateValue) { _this.address = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmailAddress.prototype, "RoutingType", {
        get: function () {
            return this.routingType;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.routingType; }, setValue: function (updateValue) { _this.routingType = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmailAddress.prototype, "MailboxType", {
        get: function () {
            return this.mailboxType;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.mailboxType; }, setValue: function (updateValue) { _this.mailboxType = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmailAddress.prototype, "Id", {
        get: function () {
            return this.id;
        },
        set: function (value) {
            var _this = this;
            this.SetFieldValue({ getValue: function () { return _this.id; }, setValue: function (updateValue) { _this.id = updateValue; } }, value);
        },
        enumerable: true,
        configurable: true
    });
    EmailAddress.prototype.InternalToJson = function (service) { throw new Error("EmailAddress.ts - InternalToJson : Not implemented."); };
    EmailAddress.prototype.LoadFromJson = function (jsonProperty, service) { throw new Error("EmailAddress.ts - LoadFromJson : Not implemented."); };
    EmailAddress.prototype.ToString = function () {
        var addressPart = null;
        if (ExtensionMethods_1.StringHelper.IsNullOrEmpty(this.Address)) {
            return ExtensionMethods_1.StringHelper.Empty;
        }
        if (!ExtensionMethods_1.StringHelper.IsNullOrEmpty(this.RoutingType)) {
            addressPart = this.RoutingType + ":" + this.Address;
        }
        else {
            addressPart = this.Address;
        }
        if (!ExtensionMethods_1.StringHelper.IsNullOrEmpty(this.Name)) {
            return this.Name + " <" + addressPart + ">";
        }
        else {
            return addressPart;
        }
    };
    EmailAddress.prototype.ReadElementsFromXmlJsObject = function (reader) { throw new Error("EmailAddress.ts - TryReadElementFromXmlJsObject : Not implemented."); };
    //todo: implement UpdateFromXmlJsObject
    EmailAddress.prototype.LoadFromXmlJsObject = function (jsonProperty, service) {
        for (var key in jsonProperty) {
            switch (key) {
                case XmlElementNames_1.XmlElementNames.Name:
                    this.name = jsonProperty[key]; //.ReadAsString(key);
                    break;
                case XmlElementNames_1.XmlElementNames.EmailAddress:
                    this.address = jsonProperty[key]; //.ReadAsString(key);
                    break;
                case XmlElementNames_1.XmlElementNames.RoutingType:
                    this.routingType = jsonProperty[key]; //.ReadAsString(key);
                    break;
                case XmlElementNames_1.XmlElementNames.MailboxType:
                    this.mailboxType = MailboxType_1.MailboxTypeParser.FromString(jsonProperty[key]); //.ReadEnumValue<MailboxType>(key);
                    break;
                case XmlElementNames_1.XmlElementNames.ItemId:
                    this.id = new ItemId_1.ItemId();
                    this.id.LoadFromXmlJsObject(jsonProperty[key], service);
                    break;
                default:
                    break;
            }
        }
    };
    EmailAddress.prototype.WriteElementsToXml = function (writer) {
        writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, XmlElementNames_1.XmlElementNames.Name, this.Name);
        writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, XmlElementNames_1.XmlElementNames.EmailAddress, this.Address);
        writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, XmlElementNames_1.XmlElementNames.RoutingType, this.RoutingType);
        writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, XmlElementNames_1.XmlElementNames.MailboxType, MailboxType_1.MailboxTypeParser.ToString(this.MailboxType));
        if (this.Id != null) {
            this.Id.WriteToXml(writer); //, XmlElementNames.ItemId);
        }
    };
    EmailAddress.SmtpRoutingType = "SMTP";
    return EmailAddress;
})(ComplexProperty_1.ComplexProperty);
exports.EmailAddress = EmailAddress;
